@@ -45,14 +45,14 @@ namespace KIPIAdvancedSlideshowPlugin
 
 typedef QMap<KUrl, QImage> LoadedImages;
 
-class SharedData;
+class SharedContainer;
 
 class LoadThread : public QThread
 {
 
 public:
 
-    LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl path,
+    LoadThread(LoadedImages* loadedImages, QMutex* imageLock, const KUrl& path,
                const int angle, int width, int height);
     ~LoadThread();
 
@@ -72,6 +72,8 @@ private:
     int           m_sheight;
 };
 
+// ----------------------------------------------------------------------------
+
 typedef QMap<KUrl, LoadThread*> LoadingThreads;
 
 class SlideShowLoader
@@ -79,12 +81,12 @@ class SlideShowLoader
 
 public:
 
-    SlideShowLoader(FileList &pathList, uint cacheSize, int width, int height,
-                    SharedData* sharedData, int beginAtIndex = 0);
+    SlideShowLoader(FileList& pathList, uint cacheSize, int width, int height,
+                    SharedContainer* sharedData, int beginAtIndex = 0);
     ~SlideShowLoader();
 
-    void next();
-    void prev();
+    void    next();
+    void    prev();
 
     QImage  getCurrent();
     QString currFileName();
@@ -94,19 +96,19 @@ private:
 
     void checkIsIn(int index);
 
-    LoadingThreads* m_loadingThreads;
-    LoadedImages*   m_loadedImages;
-    FileList        m_pathList;
+    LoadingThreads*  m_loadingThreads;
+    LoadedImages*    m_loadedImages;
+    FileList         m_pathList;
 
-    QMutex*         m_imageLock;
-    QMutex*         m_threadLock;
+    QMutex*          m_imageLock;
+    QMutex*          m_threadLock;
 
-    SharedData*     m_sharedData;
+    SharedContainer* m_sharedData;
 
-    uint            m_cacheSize;
-    int             m_currIndex;
-    int             m_swidth;
-    int             m_sheight;
+    uint             m_cacheSize;
+    int              m_currIndex;
+    int              m_swidth;
+    int              m_sheight;
 };
 
 }  // namespace KIPIAdvancedSlideshowPlugin
