@@ -51,6 +51,8 @@ namespace KIPI
 class Interface;
 }
 
+using namespace KIPI;
+
 namespace KIPIPlugins
 {
 
@@ -160,7 +162,7 @@ class CtrlButton : public QPushButton
 
 public:
 
-    CtrlButton(const QIcon& icon, QWidget* parent = 0);
+    explicit CtrlButton(const QIcon& icon, QWidget* parent = 0);
     virtual ~CtrlButton();
 };
 
@@ -193,7 +195,7 @@ public:
     };
     Q_DECLARE_FLAGS(ControlButtons, ControlButton)
 
-    explicit ImagesList(KIPI::Interface* iface, QWidget* parent = 0, int iconSize = -1);
+    explicit ImagesList(Interface* iface, QWidget* parent = 0, int iconSize = -1);
     virtual ~ImagesList();
 
     void               setAllowRAW(bool allow);
@@ -218,6 +220,7 @@ public:
 
 Q_SIGNALS:
 
+    void signalAddItems(const KUrl::List&);
     void signalImageListChanged();
     void signalFoundRAWImages(bool);
     void signalItemClicked(QTreeWidgetItem*);
