@@ -7,7 +7,7 @@
  * Description : a class to manage JPEGLossLess plugin 
  *               actions using threads
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2004-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
@@ -38,6 +38,11 @@
 
 #include "actions.h"
 
+namespace KIPI
+{
+    class Interface;
+}
+
 namespace KIPIJPEGLossLessPlugin
 {
 
@@ -49,7 +54,7 @@ class ActionThread : public QThread
 
 public:
 
-    ActionThread( KIPI::Interface* interface, QObject *parent);
+    ActionThread(KIPI::Interface* interface, QObject *parent);
     ~ActionThread();
 
     void rotate(const KUrl::List& urlList, RotateAction val);
@@ -63,9 +68,9 @@ protected:
 
 Q_SIGNALS:
 
-    void starting(const QString &filePath, int action);
-    void finished(const QString &filePath, int action);
-    void failed(const QString &filePath, int action, const QString &errString);
+    void starting(const QString& filePath, int action);
+    void finished(const QString& filePath, int action);
+    void failed(const QString& filePath, int action, const QString& errString);
 
 private:
 
