@@ -184,15 +184,15 @@ IPTCProperties::IPTCProperties(QWidget* parent)
 
     d->priorityCheck = new MetadataCheckBox(i18n("Priority:"), this);
     d->priorityCB    = new KComboBox(this);
-    d->priorityCB->insertItem(0, i18n("0: None"));
-    d->priorityCB->insertItem(1, i18n("1: High"));
+    d->priorityCB->insertItem(0, i18nc("editorial urgency of content", "0: None"));
+    d->priorityCB->insertItem(1, i18nc("editorial urgency of content", "1: High"));
     d->priorityCB->insertItem(2, "2");
     d->priorityCB->insertItem(3, "3");
     d->priorityCB->insertItem(4, "4");
-    d->priorityCB->insertItem(5, i18n("5: Normal"));
+    d->priorityCB->insertItem(5, i18nc("editorial urgency of content", "5: Normal"));
     d->priorityCB->insertItem(6, "6");
     d->priorityCB->insertItem(7, "7");
-    d->priorityCB->insertItem(8, i18n("8: Low"));
+    d->priorityCB->insertItem(8, i18nc("editorial urgency of content", "8: Low"));
     d->priorityCB->setWhatsThis(i18n("Select here the editorial urgency of content."));
 
     // --------------------------------------------------------
