@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "singledialog.h"
 #include "singledialog.moc"
 
 // C ANSI includes
@@ -78,11 +77,12 @@ extern "C"
 #include "actionthread.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-#include "previewwidget.h"
+#include "previewimage.h"
 #include "rawdecodingiface.h"
 #include "savesettingswidget.h"
 
 using namespace KDcrawIface;
+using namespace KIPIPlugins;
 
 namespace KIPIRawConverterPlugin
 {
@@ -93,10 +93,6 @@ public:
 
     SingleDialogPriv()
     {
-        previewBlink        = false;
-        convertBlink        = false;
-        blinkPreviewTimer   = 0;
-        blinkConvertTimer   = 0;
         previewWidget       = 0;
         thread              = 0;
         saveSettingsBox     = 0;
@@ -105,27 +101,21 @@ public:
         iface               = 0;
     }
 
-    bool                      previewBlink;
-    bool                      convertBlink;
+    QString              inputFileName;
 
-    QString                   inputFileName;
+    KUrl                 inputFile;
 
-    QTimer                   *blinkPreviewTimer;
-    QTimer                   *blinkConvertTimer;
+    PreviewImage*        previewWidget;
 
-    KUrl                      inputFile;
+    ActionThread*        thread;
 
-    PreviewWidget            *previewWidget;
+    SaveSettingsWidget*  saveSettingsBox;
 
-    ActionThread             *thread;
+    DcrawSettingsWidget* decodingSettingsBox;
 
-    SaveSettingsWidget       *saveSettingsBox;
+    KPAboutData*         about;
 
-    DcrawSettingsWidget      *decodingSettingsBox;
-
-    KIPIPlugins::KPAboutData *about;
-
-    KIPI::Interface          *iface;
+    KIPI::Interface*     iface;
 };
 
 SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
@@ -133,7 +123,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 {
     d->iface = iface;
     setButtons(Help | Default | User1 | User2 | User3 | Close);
-    setDefaultButton(KDialog::Close);
+    setDefaultButton(Close);
     setButtonText(User1, i18n("&Preview"));
     setButtonText(User2, i18n("Con&vert"));
     setButtonText(User3, i18n("&Abort"));
@@ -144,15 +134,15 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     setMainWidget( page );
     QGridLayout *mainLayout = new QGridLayout(page);
 
-    d->previewWidget = new PreviewWidget(page);
+    d->previewWidget        = new PreviewImage(page);
 
     // ---------------------------------------------------------------
 
-    d->decodingSettingsBox = new DcrawSettingsWidget(page, DcrawSettingsWidget::SIXTEENBITS |
-                                                           DcrawSettingsWidget::COLORSPACE |
-                                                           DcrawSettingsWidget::POSTPROCESSING |
-                                                           DcrawSettingsWidget::BLACKWHITEPOINTS);
-    d->saveSettingsBox     = new SaveSettingsWidget(d->decodingSettingsBox);
+    d->decodingSettingsBox  = new DcrawSettingsWidget(page, DcrawSettingsWidget::SIXTEENBITS |
+                                                            DcrawSettingsWidget::COLORSPACE |
+                                                            DcrawSettingsWidget::POSTPROCESSING |
+                                                            DcrawSettingsWidget::BLACKWHITEPOINTS);
+    d->saveSettingsBox      = new SaveSettingsWidget(d->decodingSettingsBox);
 
 #if KDCRAW_VERSION <= 0x000500
     d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"));
@@ -212,18 +202,10 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 
     setButtonToolTip(Close, i18n("Exit RAW Converter"));
 
-    d->blinkPreviewTimer = new QTimer(this);
-    d->blinkConvertTimer = new QTimer(this);
-    d->thread            = new ActionThread(this, d->iface->hostSetting("WriteMetadataUpdateFiletimeStamp").toBool());
+    d->thread = new ActionThread(this, d->iface->hostSetting("WriteMetadataUpdateFiletimeStamp").toBool());
 
     // ---------------------------------------------------------------
 
-    connect(d->blinkPreviewTimer, SIGNAL(timeout()),
-            this, SLOT(slotPreviewBlinkTimerDone()));
-
-    connect(d->blinkConvertTimer, SIGNAL(timeout()),
-            this, SLOT(slotConvertBlinkTimerDone()));
-
     connect(d->decodingSettingsBox, SIGNAL(signalSixteenBitsImageToggled(bool)),
             d->saveSettingsBox, SLOT(slotPopulateImageFormat(bool)));
 
@@ -287,8 +269,6 @@ void SingleDialog::slotSixteenBitsImageToggled(bool)
 void SingleDialog::closeEvent(QCloseEvent *e)
 {
     if (!e) return;
-    d->blinkPreviewTimer->stop();
-    d->blinkConvertTimer->stop();
     d->thread->cancel();
     saveSettings();
     e->accept();
@@ -296,8 +276,6 @@ void SingleDialog::closeEvent(QCloseEvent *e)
 
 void SingleDialog::slotClose()
 {
-    d->blinkPreviewTimer->stop();
-    d->blinkConvertTimer->stop();
     d->thread->cancel();
     saveSettings();
     done(Close);
@@ -346,14 +324,7 @@ void SingleDialog::readSettings()
         (KDcrawIface::RawDecodingSettings::OutputColorSpace)group.readEntry("Output Color Space",
             (int)(KDcrawIface::RawDecodingSettings::SRGB)));
 
-    d->saveSettingsBox->setFileFormat(
-        (SaveSettingsWidget::OutputFormat)group.readEntry("Output Format",
-            (int)(SaveSettingsWidget::OUTPUT_PNG)));
-
-    d->saveSettingsBox->setConflictRule(
-        (SaveSettingsWidget::ConflictRule)group.readEntry("Conflict",
-            (int)(SaveSettingsWidget::OVERWRITE)));
-
+    d->saveSettingsBox->readSettings(group);
     d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->sixteenBits());
 
     KConfigGroup group2 = config.group(QString("Single Raw Converter Dialog"));
@@ -388,8 +359,8 @@ void SingleDialog::saveSettings()
 #if KDCRAW_VERSION >= 0x000500
     group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
 #endif
-    group.writeEntry("Output Format", (int)d->saveSettingsBox->fileFormat());
-    group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
+
+    d->saveSettingsBox->writeSettings(group);
 
     KConfigGroup group2 = config.group(QString("Single Raw Converter Dialog"));
     saveDialogSize(group2);
@@ -506,7 +477,7 @@ void SingleDialog::busy(bool val)
 
 void SingleDialog::setIdentity(const KUrl& /*url*/, const QString& identity)
 {
-    d->previewWidget->setIdentity(d->inputFileName + QString(" :\n") + identity, Qt::white);
+    d->previewWidget->setText(d->inputFileName + QString(" :\n") + identity, Qt::white);
 }
 
 void SingleDialog::setThumbnail(const KUrl& url, const QPixmap& thumbnail)
@@ -517,37 +488,27 @@ void SingleDialog::setThumbnail(const KUrl& url, const QPixmap& thumbnail)
 
 void SingleDialog::previewing(const KUrl& /*url*/)
 {
-    d->previewBlink = false;
-    d->previewWidget->setCursor( Qt::WaitCursor );
-    d->blinkPreviewTimer->start(200);
+    d->previewWidget->setBusy(true, i18n("Generating Preview..."));
 }
 
 void SingleDialog::previewed(const KUrl& /*url*/, const QString& tmpFile)
 {
-    d->previewWidget->unsetCursor();
-    d->blinkPreviewTimer->stop();
     d->previewWidget->load(tmpFile);
     ::remove(QFile::encodeName(tmpFile));
 }
 
 void SingleDialog::previewFailed(const KUrl& /*url*/)
 {
-    d->previewWidget->unsetCursor();
-    d->blinkPreviewTimer->stop();
-    d->previewWidget->setIdentity(i18n("Failed to generate preview"), Qt::red);
+    d->previewWidget->setText(i18n("Failed to generate preview"), Qt::red);
 }
 
 void SingleDialog::processing(const KUrl& /*url*/)
 {
-    d->convertBlink = false;
-    d->previewWidget->setCursor( Qt::WaitCursor );
-    d->blinkConvertTimer->start(200);
+    d->previewWidget->setBusy(true, i18n("Processing Images..."));
 }
 
 void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
 {
-    d->previewWidget->unsetCursor();
-    d->blinkConvertTimer->stop();
     d->previewWidget->load(tmpFile);
     QString filter("*.");
     QString ext;
@@ -619,35 +580,8 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
 
 void SingleDialog::processingFailed(const KUrl& /*url*/)
 {
-    d->previewWidget->unsetCursor();
-    d->blinkConvertTimer->stop();
-    d->previewWidget->setIdentity(i18n("Failed to convert RAW image"), Qt::red);
-}
-
-void SingleDialog::slotPreviewBlinkTimerDone()
-{
-    QString preview = i18n("Generating Preview...");
-
-    if (d->previewBlink)
-        d->previewWidget->setIdentity(preview, Qt::green);
-    else
-        d->previewWidget->setIdentity(preview, Qt::darkGreen);
-
-    d->previewBlink = !d->previewBlink;
-    d->blinkPreviewTimer->start(200);
-}
-
-void SingleDialog::slotConvertBlinkTimerDone()
-{
-    QString convert = i18n("Converting RAW Image...");
-
-    if (d->convertBlink)
-        d->previewWidget->setIdentity(convert, Qt::green);
-    else
-        d->previewWidget->setIdentity(convert, Qt::darkGreen);
-
-    d->convertBlink = !d->convertBlink;
-    d->blinkConvertTimer->start(200);
+    d->previewWidget->setBusy(false);
+    d->previewWidget->setText(i18n("Failed to convert RAW image"), Qt::red);
 }
 
 void SingleDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
