@@ -20,7 +20,6 @@
  *
  * ============================================================ */
 
-#include "clockphotodialog.h"
 #include "clockphotodialog.moc"
 
 // Qt includes
@@ -325,8 +324,8 @@ bool ClockPhotoDialog::setImage(KUrl imageFile)
                 // warning and disable the datetime widget.
                 QString warning = i18n("<font color=\"red\"><b>Could not "
                                        "obtain date and time information "
-                                       "from image %1.</b></font>").
-                                       arg(imageFile.fileName());
+                                       "from image %1.</b></font>",
+                                       imageFile.fileName());
                 d->imageLabel->setText(warning);
             }
         }
@@ -336,8 +335,8 @@ bool ClockPhotoDialog::setImage(KUrl imageFile)
         // If the image couldn't be loaded, display a warning, disable all the
         // GUI elements and load an empty photo into d->image.
         QString warning = i18n("<font color=\"red\"><b>Could not load "
-                               "image %1.</b></font>").
-                               arg(imageFile.fileName());
+                               "image %1.</b></font>",
+                               imageFile.fileName());
         d->imageLabel->setText(warning);
     }
 
